__title__ = "seafoam"
__version__ = "2.17.0"
__description__ = "Pelican theme, first used for Minchin.ca."
__author__ = "W. Minchin"
__email__ = "w_minchin@hotmail.com"
__url__ = "http://blog.minchin.ca/label/seafoam/"
__license__ = "MIT License"

LOG_PREFIX = "[Seafoam]"
PLUGIN_LIST: list[str] = [
    "pelican.plugins.seafoam",
    "pelican.plugins.jinja_filters",
]
PRODUCTION_PLUGIN_LIST: list[str] = PLUGIN_LIST + [
    "pelican.plugins.image_process",
]
STYLES: list[str] = [
    "seafoam",
    "strathcona",
]



import logging

from bs4 import BeautifulSoup

from .constants import LOG_PREFIX

logger = logging.getLogger(__name__)


# def table_fix(html_fragment, settings):
def table_fix(path, context):
    """
    Apply the ``.table`` class to all HTML tables within generated articles.

    This is so the Bootstrap CSS works as expected.

    Note that BeautifulSoup's round-tripping (parsing and re-writing) is not
    "pixel perfect" and may change the final HTML. In particular, the `lxml`
    and `html5lib` parser will add the `<html>` and `<body>` if they are
    missing. Here, we are dealing with the entire HTML document, so that
    particular change, if it happens, shouldn't be an issue.
    """
    REWRITE = False

    with open(path, "r+", encoding=context["SEAFOAM_ENCODING"]) as f:
        soup = BeautifulSoup(f, context["SEAFOAM_PARSER"])

        for table in soup.find_all("table"):
            try:
                if "table" not in table["class"]:
                    table["class"].append("table")
                    REWRITE = True
            except KeyError:
                table["class"] = "table"
                REWRITE = True

        if REWRITE:
            logging.debug('%s table fix for "%s"' % (LOG_PREFIX, path))
            f.seek(0)
            f.truncate()
            f.write(str(soup))



import logging

from pelican import signals

logger = logging.getLogger(__name__)

def add_jinja_debug(pelican):
    """
    Allows the use of the ``{% debug %}`` filter in templates.

    See https://jinja.palletsprojects.com/en/stable/extensions/#debug-extension
    """
    pelican.env.add_extension("jinja2.ext.debug")
